.. include:: /_includes/wip_prolog.rst

:mod:`stix.campaign` Module
==================================

.. module:: stix.campaign

Classes
-------

.. autoclass:: Campaign
	:show-inheritance:
	:members:

.. autoclass:: AssociatedCampaigns
	:show-inheritance:
	:members:

.. autoclass:: Attribution
	:show-inheritance:
	:members:

.. autoclass:: Names
	:show-inheritance:
	:members:

.. autoclass:: RelatedIncidents
	:show-inheritance:
	:members:

.. autoclass:: RelatedIndicators
	:show-inheritance:
	:members:

.. autoclass:: RelatedTTPs
	:show-inheritance:
	:members:
